@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -22,7 +22,7 @@
 #include <QLabel>
 #include <klineedit.h>
 #include <pimcommon/minimumcombobox.h>
-#include <libkdepim/tagwidgets.h>
+#include <libkdepimakonadi/tagwidgets.h>
 #include <AkonadiWidgets/CollectionComboBox>
 
 FilterActionAddToAddressBookTest::FilterActionAddToAddressBookTest(QObject *parent)
@@ -39,7 +39,7 @@ FilterActionAddToAddressBookTest::~FilterActionAddToAddressBookTest()
 void FilterActionAddToAddressBookTest::shouldHaveDefaultValue()
 {
     MailCommon::FilterActionAddToAddressBook filter;
-    QWidget *w = filter.createParamWidget(0);
+    QWidget *w = filter.createParamWidget(nullptr);
 
     PimCommon::MinimumComboBox *headerCombo = w->findChild<PimCommon::MinimumComboBox *>(QStringLiteral("HeaderComboBox"));
     QVERIFY(headerCombo);
