@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -30,7 +30,7 @@ class FilterActionMissingAccountDialog : public QDialog
 public:
     explicit FilterActionMissingAccountDialog(const QStringList &lstAccount,
             const QString &filtername,
-            QWidget *parent = Q_NULLPTR);
+            QWidget *parent = nullptr);
     ~FilterActionMissingAccountDialog();
     QStringList selectedAccount() const;
     static bool allAccountExist(const QStringList &lst);
