@@ -1,6 +1,6 @@
 /*
 
-  Copyright (c) 2012-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -27,7 +27,7 @@ class FilterActionUnsetStatus: public FilterActionStatus
 {
     Q_OBJECT
 public:
-    explicit FilterActionUnsetStatus(QObject *parent = Q_NULLPTR);
+    explicit FilterActionUnsetStatus(QObject *parent = nullptr);
     ReturnCode process(ItemContext &context, bool applyOnOutbound) const Q_DECL_OVERRIDE;
     SearchRule::RequiredPart requiredPart() const Q_DECL_OVERRIDE;
 
