@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -38,7 +38,7 @@ class FilterSelectionDialog : public QDialog
     Q_OBJECT
 
 public:
-    explicit FilterSelectionDialog(QWidget *parent = Q_NULLPTR);
+    explicit FilterSelectionDialog(QWidget *parent = nullptr);
     virtual ~FilterSelectionDialog();
     void setFilters(const QList<MailFilter *> &filters);
     QList<MailFilter *> selectedFilters() const;
