@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -107,7 +107,7 @@ public:
      * @param function The function to use for searching.
      * @param contents The contents to search for.
      */
-    static SearchRule::Ptr createInstance(const QByteArray &field = 0,
+    static SearchRule::Ptr createInstance(const QByteArray &field = QByteArray(),
                                           Function function = FuncContains,
                                           const QString &contents = QString());
 
