@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -79,7 +79,7 @@ void RedirectWidget::setFocus()
 
 void RedirectWidget::slotAddressSelection()
 {
-    QScopedPointer<Akonadi::EmailAddressSelectionDialog> dlg(
+    std::unique_ptr<Akonadi::EmailAddressSelectionDialog> dlg(
         new Akonadi::EmailAddressSelectionDialog(this));
 
     dlg->view()->view()->setSelectionMode(QAbstractItemView::MultiSelection);
@@ -88,7 +88,9 @@ void RedirectWidget::slotAddressSelection()
 
     if (dlg->exec() != QDialog::Rejected && dlg) {
         QStringList addresses;
-        foreach (const Akonadi::EmailAddressSelection &selection, dlg->selectedAddresses()) {
+        const Akonadi::EmailAddressSelection::List lstAddress = dlg->selectedAddresses();
+        addresses.reserve(lstAddress.count());
+        for (const Akonadi::EmailAddressSelection &selection : lstAddress) {
             addresses << selection.quotedEmail();
         }
 
